package com.kdanmobile.kdanloginregisterui

import com.kdanmobile.kdanloginregisterui.Utils.toSpannable

import android.content.Context
import android.text.method.LinkMovementMethod
import android.util.AttributeSet
import android.view.View
import android.widget.TextView
import androidx.constraintlayout.widget.ConstraintLayout

open abstract class BaseLoginView @JvmOverloads constructor(
    context: Context,
    attrs: AttributeSet? = null,
    defStyleAttr: Int = 0
) : ConstraintLayout(context, attrs, defStyleAttr) {

    abstract var email: String
    abstract var pwd: String
    abstract var isRemember: Boolean

    lateinit var onClickEmailLogin: Runnable
    lateinit var onClickFbLogin: Runnable
    lateinit var onClickGoogleLogin: Runnable
    lateinit var onClickTurnOfService: Runnable
    lateinit var onClickPrivacyPolicy: Runnable
    lateinit var onClickSwitchToRegister: Runnable
    lateinit var onClickPwdHelp: Runnable
    lateinit var onClickClose: Runnable

    protected fun setupTosAndPpTextView(textView: TextView) {
        val tos = context.getString(R.string.kdanlrui_terms_of_service)
        val pp = context.getString(R.string.kdanlrui_privacy_policy)
        val textColor = resources.getColor(R.color.kdanlrui_tos_pp_text)
        val tosSS = tos.toSpannable(textColor, false, View.OnClickListener { v -> onClickTurnOfService.run() })
        val ppSS = pp.toSpannable(textColor, false, View.OnClickListener { v -> onClickPrivacyPolicy.run() })
        textView.apply {
            movementMethod = LinkMovementMethod.getInstance()
            append(tosSS)
            append(" & ")
            append(ppSS)
        }
    }

    protected fun setupSwitchTextView(textView: TextView) {
        val s = textView.text
        val textColor = resources.getColor(R.color.kdanlrui_switch_text)
        val ss = s.toSpannable(textColor, true, View.OnClickListener { v -> onClickSwitchToRegister.run() })
        textView.apply {
            movementMethod = LinkMovementMethod.getInstance()
            text = ss
        }
    }
}