package com.kdanmobile.kdanloginregisterui

import android.content.Context
import androidx.constraintlayout.widget.ConstraintLayout
import android.text.TextUtils
import android.util.AttributeSet
import android.view.View
import kotlinx.android.synthetic.main.activity_bind_account.view.*
import org.apache.commons.validator.routines.EmailValidator

class BindAccountView @JvmOverloads constructor(
    context: Context,
    attrs: AttributeSet? = null,
    defStyleAttr: Int = 0
) : ConstraintLayout(context, attrs, defStyleAttr) {

    var existingEmail: String
        get() = et_bindAccount_existingEmail.text.toString()
        set(value) {}
    var existingPwd: String
        get() = et_bindAccount_existingPwd.text.toString()
        set(value) {}
    val newEmail: String
        get() = et_bindAccount_newEmail.text.toString()

    lateinit var onClickConnect: Runnable
    lateinit var onClickCreate: Runnable
    lateinit var onClickBack: Runnable

    init {
        View.inflate(context, R.layout.activity_bind_account, this)
        setThirdPtyName("Google")
        btn_bindAccount_back.setOnClickListener { onClickBack.run() }
        btn_bindAccount_create.setOnClickListener { onClickCreateBtn() }
        btn_bindAccount_bind.setOnClickListener { onClickConnectBtn() }
    }

    fun setThirdPtyName(name: String) {
        tv_bindAccount_bind.text = context.getString(R.string.kdanlrui_bind_account_bind_text, name)
        tv_bindAccount_bindExplanation.text = context.getString(R.string.kdanlrui_bind_account_bind_explanation, name)
    }

    private fun onClickCreateBtn() {
        val isEmailValid = !TextUtils.isEmpty(newEmail) && EmailValidator.getInstance().isValid(newEmail)
        et_bindAccount_newEmail.error = when (isEmailValid) {
            true -> null
            false -> context.getString(R.string.kdanlrui_email_login_register_dialog_email_error)
        }
        if (isEmailValid) {
            onClickCreate.run()
        }
    }

    private fun onClickConnectBtn() {
        val isEmailValid = !TextUtils.isEmpty(existingEmail) && EmailValidator.getInstance().isValid(existingEmail)
        val isPwdValid = !TextUtils.isEmpty(existingPwd)
        et_bindAccount_existingEmail.error = when {
            isEmailValid -> null
            else -> context.getString(R.string.kdanlrui_email_login_register_dialog_email_error)
        }
        et_bindAccount_existingPwd.error = when {
            isPwdValid -> null
            else -> context.getString(R.string.kdanlrui_email_login_register_dialog_pwd_error)
        }
        if (isEmailValid && isPwdValid) {
            onClickConnect.run()
        }
    }


}