package com.kdanmobile.kdanloginregisterui.widget

import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.view.View
import android.view.View.OnClickListener
import android.widget.TextView
import androidx.constraintlayout.widget.ConstraintLayout
import com.kdanmobile.kdanloginregisterui.Config
import com.kdanmobile.kdanloginregisterui.R
import com.kdanmobile.kdanloginregisterui.Utils.toSpannable
import kotlinx.android.synthetic.main.view_email_login_form.view.*
import org.apache.commons.validator.routines.EmailValidator

class EmailLoginFormView @JvmOverloads constructor(
    context: Context,
    attrs: AttributeSet? = null,
    defStyleAttr: Int = 0
) : ConstraintLayout(context, attrs, defStyleAttr) {

    var onSubmit: Runnable? = null
    var onClickPwdHelp: View.OnClickListener? = null

    var isRemember: Boolean
        get() {
            return cb_emailLogin_rememberMe.isChecked
        }
        set(value) {
            cb_emailLogin_rememberMe.isChecked = value
        }
    var email: String
        get() {
            return et_emailLoginForm_email.text.toString()
        }
        set(value) {
            et_emailLoginForm_email.setText(value, TextView.BufferType.EDITABLE)
        }
    var pwd: String
        get() {
            return et_emailLoginForm_pwd.text.toString()
        }
        set(value) {
            return et_emailLoginForm_pwd.setText(value, TextView.BufferType.EDITABLE)
        }

    init {
        inflate(getContext(), R.layout.view_email_login_form, this)
        btn_emailLoginForm_login.setOnClickListener { onClickSubmitBtn() }
        setupPwdHelpTv()
    }

    private fun onClickSubmitBtn() {
        val isEmailValid = !TextUtils.isEmpty(email) && EmailValidator.getInstance().isValid(email)
        val isPwdValid = !TextUtils.isEmpty(pwd) && pwd.length >= Config.PWD_MIN_LENGTH
        et_emailLoginForm_email.error = when {
            isEmailValid -> null
            else -> context.getString(R.string.kdanlrui_email_login_register_dialog_email_error)
        }
        et_emailLoginForm_pwd.error = when {
            isPwdValid -> null
            else -> context.getString(R.string.kdanlrui_email_login_register_dialog_pwd_error)
        }
        if (isEmailValid && isPwdValid)
            onSubmit?.run()
    }

    private fun setupPwdHelpTv() {
        val textColor = resources.getColor(R.color.kdanlrui_email_login_pwd_helper)
        val isUnderLine = true
        val onClick = OnClickListener {} // Cannot work, don't know why.
        val s = tv_emailLogin_pwdHelp.text
            .toSpannable(textColor, isUnderLine, onClick)
        tv_emailLogin_pwdHelp.text = s

        // The OnClickListener set on spannable is now work,
        // so use the simple way.
        tv_emailLogin_pwdHelp.setOnClickListener {
            onClickPwdHelp?.onClick(it)
        }
    }
}
