package com.kdanmobile.kdanloginregisterui.widget

import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.widget.TextView
import androidx.constraintlayout.widget.ConstraintLayout
import com.kdanmobile.kdanloginregisterui.R
import kotlinx.android.synthetic.main.view_email_register_form.view.*
import org.apache.commons.validator.routines.EmailValidator

class EmailRegisterFormView @JvmOverloads constructor(
    context: Context,
    attrs: AttributeSet? = null,
    defStyleAttr: Int = 0
) : ConstraintLayout(context, attrs, defStyleAttr) {

    companion object {
        const val PWD_MIN_LENGTH = 8
    }

    var onSubmit: Runnable? = null
    var name: String
        get() {
            return et_emailRegisterForm_name.text.toString()
        }
        set(value) {
            et_emailRegisterForm_name.setText(value, TextView.BufferType.EDITABLE)
        }
    var email: String
        get() {
            return et_emailRegisterForm_email.text.toString()
        }
        set(value) {
            et_emailRegisterForm_email.setText(value, TextView.BufferType.EDITABLE)
        }
    var pwd: String
        get() {
            return et_emailRegisterForm_pwd.text.toString()
        }
        set(value) {
            return et_emailRegisterForm_pwd.setText(value, TextView.BufferType.EDITABLE)
        }

    init {
        inflate(getContext(), R.layout.view_email_register_form, this)
        btn_emailRegisterForm_submit.setOnClickListener { onClickSubmitBtn() }
    }

    private fun onClickSubmitBtn() {
        val isNameValid = !TextUtils.isEmpty(name)
        val isEmailValid = !TextUtils.isEmpty(email) && EmailValidator.getInstance().isValid(email)
        val isPwdValid = !TextUtils.isEmpty(pwd) && pwd.length >= PWD_MIN_LENGTH
        et_emailRegisterForm_name.error = when {
            isNameValid -> null
            else -> context.getString(R.string.kdanlrui_email_login_register_dialog_name_error)
        }
        et_emailRegisterForm_email.error = when {
            isEmailValid -> null
            else -> context.getString(R.string.kdanlrui_email_login_register_dialog_email_error)
        }
        et_emailRegisterForm_pwd.error = when {
            isPwdValid -> null
            else -> context.getString(R.string.kdanlrui_email_login_register_dialog_pwd_error)
        }
        if (isNameValid && isEmailValid && isPwdValid)
            onSubmit?.run()
    }
}
